@@ -40,7 +40,32 @@ def list_jobs(project_id):
     r = make_request(url)
     data = r.json()['data']
     for j in data:
-        del(j['relationships'])
+        del (j['relationships'])
+    return data
+
+
+def create_job_export_file(job_id, raw, worker_data):
+    global logger
+    logger = settings.get_logger()
+
+    url = f'/export_files'
+    headers = {'content-type': 'application/vnd.api+json', 'accept': 'application/vnd.api+json'}
+
+    data = {
+        'data': {
+            "type": "export_files",
+            "attributes": {
+                "jobId": f'{job_id}',
+                "type": 'raw' if raw else 'target',
+                "allJudgements": worker_data and not raw,
+                "includeWorkerData": worker_data and not raw
+            }
+        }
+    }
+
+    r = make_request(url, headers=headers, json=data)
+    data = r.json()['data']
+    del data['relationships']
     return data
 
 
