@@ -1,7 +1,7 @@
 import argparse
 from datetime import datetime
 from django.utils.text import slugify
-from tasq_cli import jobs
+from tasq_cli import jobs, export_files
 from tasq_cli import projects
 from tasq_cli import settings
 from tasq_cli.upload import do_upload, create_csv_from_currently_uploaded_files, upload_csv
@@ -48,8 +48,27 @@ def main():
     export_job_parser.add_argument('--raw', action='store_true', help='the job id')
     export_job_parser.add_argument('--worker_data', action='store_true', help='include worker data')
 
+    export_file_job_parser = subparsers.add_parser('create-job-export-file', help='creates an export file for a job')
+    export_file_job_parser.add_argument('job_id', help='the job id')
+    export_file_job_parser.add_argument('--raw', action='store_true', help='the job id')
+    export_file_job_parser.add_argument('--worker_data', action='store_true', help='include worker data')
+
+    export_file_project_parser = subparsers.add_parser('create-project-export-file', help='creates an export file for a project')
+    export_file_project_parser.add_argument('project_id', help='the project id')
+    export_file_project_parser.add_argument('--raw', action='store_true', help='the project id')
+    export_file_project_parser.add_argument('--worker_data', action='store_true', help='include worker data')
+
     list_projects_parser = subparsers.add_parser('list-projects', help='list all projects')
 
+    get_export_link = subparsers.add_parser('get-export-link',
+                                                       help='get a link to an export file, which is '
+                                                            'not necessarily populated yet')
+    get_export_link.add_argument('export_file_id', help='the export file id')
+
+    get_export_file = subparsers.add_parser('get-export-file',
+                                                help='get export file details')
+    get_export_file.add_argument('export_file_id', help='the export file id')
+
     args = parser.parse_args()
     logger = settings.get_logger()
 
@@ -102,8 +121,16 @@ def main():
         result = jobs.list_jobs(args.project_id)
     if args.action == 'export-job':
         result = jobs.export_job(args.job_id, args.raw, args.worker_data)
+    if args.action == 'create-job-export-file':
+        result = jobs.create_job_export_file(args.job_id, args.raw, args.worker_data)
+    if args.action == 'create-project-export-file':
+        result = projects.create_project_export_file(args.project_id, args.raw, args.worker_data)
     if args.action == 'list-projects':
         result = projects.list_projects()
+    if args.action == 'get-export-link':
+        result = export_files.get_export_link(args.export_file_id)
+    if args.action == 'get-export-file':
+        result = export_files.get_export_file(args.export_file_id)
 
     if result:
         print(result)
